Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(348)

Unified Diff: third_party/WebKit/Source/core/html/forms/FileInputType.cpp

Issue 1373773003: Implement 'window.isSecureContext'. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: document. Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/html/forms/FileInputType.cpp
diff --git a/third_party/WebKit/Source/core/html/forms/FileInputType.cpp b/third_party/WebKit/Source/core/html/forms/FileInputType.cpp
index db3d2ffcb1fe86b513f69d490a1aa741418a7908..c672cb28691b155f4af8fa0b2cf5692e9e0ff0e4 100644
--- a/third_party/WebKit/Source/core/html/forms/FileInputType.cpp
+++ b/third_party/WebKit/Source/core/html/forms/FileInputType.cpp
@@ -242,12 +242,12 @@ FileList* FileInputType::createFileList(const Vector<FileChooserFileInfo>& files
void FileInputType::countUsage()
{
// It is required by isPrivilegedContext() but isn't
// actually used. This could be used later if a warning is shown in the
// developer console.
String insecureOriginMsg;
Document* document = &element().document();
- if (document->isPrivilegedContext(insecureOriginMsg))
+ if (document->isSecureContext(insecureOriginMsg))
UseCounter::count(*document, UseCounter::InputTypeFileInsecureOrigin);
else
UseCounter::count(*document, UseCounter::InputTypeFileSecureOrigin);
@@ -242,12 +242,12 @@ FileList* FileInputType::createFileList(const Vector<FileChooserFileInfo>& files
void FileInputType::countUsage()
{
- // It is required by isPrivilegedContext() but isn't
+ // It is required by isSecureContext() but isn't
// actually used. This could be used later if a warning is shown in the
// developer console.
« no previous file with comments | « third_party/WebKit/Source/core/frame/Window.idl ('k') | third_party/WebKit/Source/core/testing/NullExecutionContext.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698